package com.retrytech.deliveryboy.adapters;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.bumptech.glide.Glide;
import com.retrytech.deliveryboy.R;
import com.retrytech.deliveryboy.VegiUtils;
import com.retrytech.deliveryboy.databinding.ItemProductsBinding;
import com.retrytech.deliveryboy.models.OrderDetailRoot;
import com.retrytech.deliveryboy.retrofit.Const;

import java.text.DecimalFormat;
import java.util.List;

public class OrderItemAdapter extends RecyclerView.Adapter<OrderItemAdapter.ItemViewHolder> {
    private List<OrderDetailRoot.OrderproductsItem> itemDetails;
    private Context context;
    private DecimalFormat df;

    public OrderItemAdapter(List<OrderDetailRoot.OrderproductsItem> itemDetails) {

        this.itemDetails = itemDetails;
    }

    @NonNull
    @Override
    public ItemViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        context = parent.getContext();
        df = new DecimalFormat("###.##");
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_products, parent, false);
        return new ItemViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ItemViewHolder holder, int position) {
        holder.setmodel(itemDetails.get(position));
    }

    @Override
    public int getItemCount() {
        return itemDetails.size();
    }

    public class ItemViewHolder extends RecyclerView.ViewHolder {
        ItemProductsBinding binding;

        public ItemViewHolder(@NonNull View itemView) {
            super(itemView);
            binding = ItemProductsBinding.bind(itemView);
        }

        public void setmodel(OrderDetailRoot.OrderproductsItem itemDetail) {
            binding.productName.setText(itemDetail.getProductName());
            binding.produxtWeight.setText(df.format(Float.parseFloat(itemDetail.getPriceUnit())).concat(" ") + itemDetail.getPriceUnitName());
            binding.tvproductprice.setText(VegiUtils.currency + df.format(Float.parseFloat(itemDetail.getPrice())));
            binding.produxtQuentity.setText(context.getString(R.string.quentity).concat(" : ") + itemDetail.getQuantity());
            Glide.with(binding.getRoot().getContext())
                    .load(Const.BASE_IMG_URL + itemDetail.getImage())
                    .placeholder(R.drawable.placeholder)
                    .error(R.drawable.placeholder)
                    .into(binding.imgProduct);

        }
    }
}
