package com.retrytech.deliveryboy.adapters;

import android.content.Context;
import android.content.Intent;
import android.location.Location;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.bumptech.glide.Glide;
import com.google.gson.Gson;
import com.retrytech.deliveryboy.R;
import com.retrytech.deliveryboy.activites.OrderDetailActivity;
import com.retrytech.deliveryboy.databinding.ItemOrderlistBinding;
import com.retrytech.deliveryboy.models.DistanceRoot;
import com.retrytech.deliveryboy.models.PendingOrdersRoot;
import com.retrytech.deliveryboy.retrofit.Const;
import com.retrytech.deliveryboy.retrofit.RetrofitBuilder;

import java.util.ArrayList;
import java.util.List;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class PendingOrderAdapter extends RecyclerView.Adapter<PendingOrderAdapter.OrderViewHolder> {
    private List<PendingOrdersRoot.DataItem> data = new ArrayList<PendingOrdersRoot.DataItem>();
    private Context context;
    private Location lastKnownLocation = null;


    @NonNull
    @Override
    public OrderViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        context = parent.getContext();
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_orderlist, parent, false);
        return new OrderViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull OrderViewHolder holder, int position) {
        holder.setModel(data.get(position));


    }

    @Override
    public int getItemCount() {
        return data.size();
    }

    public void addData(List<PendingOrdersRoot.DataItem> data) {

        for (int i = 0; i < data.size(); i++) {
            this.data.add(data.get(i));
            notifyItemInserted(this.data.size() - 1);
        }

    }

    public void setLocation(Location lastKnownLocation) {

        this.lastKnownLocation = lastKnownLocation;
        notifyDataSetChanged();
    }

    private void getDistance(PendingOrdersRoot.Orderaddress addressObj, ItemOrderlistBinding binding) {
        String s = makeURL(lastKnownLocation.getLatitude(), lastKnownLocation.getLongitude(), addressObj.getLatitude(), addressObj.getLongitude());
        Log.d("TAG", "getDistance: " + s);

        StringBuilder origin = new StringBuilder();
        origin.append(Double.toString(lastKnownLocation.getLatitude()));
        origin.append(",");
        origin.append(Double.toString(lastKnownLocation.getLongitude()));

        StringBuilder destination = new StringBuilder();
        destination
                .append(addressObj.getLatitude());
        destination.append(",");
        destination.append(addressObj.getLongitude());

        Call<DistanceRoot> call = RetrofitBuilder.distanceService().getDistance(origin.toString(), destination.toString(), context.getString(R.string.map_api_key));
        call.enqueue(new Callback<DistanceRoot>() {
            @Override
            public void onResponse(Call<DistanceRoot> call, Response<DistanceRoot> response) {
                if (response.code() == 200 && response.body() != null) {
                    if (response.body().getRows() != null && !response.body().getRows().isEmpty()) {
                        if (response.body().getRows().get(0) != null) {
                            if (response.body().getRows().get(0).getElements() != null && !response.body().getRows().get(0).getElements().isEmpty()) {
                                if (response.body().getRows().get(0).getElements().get(0) != null) {
                                    if (response.body().getRows().get(0).getElements().get(0).getDistance() != null) {
                                        if (response.body().getRows().get(0).getElements().get(0).getDistance().getText() != null) {
                                            String distance = response.body().getRows().get(0).getElements().get(0).getDistance().getText();
                                            binding.tvdistence.setText(distance);
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            @Override
            public void onFailure(Call<DistanceRoot> call, Throwable t) {

            }
        });

    }

    public String makeURL(double sourcelat, double sourcelog, String destlat, String destlog) {
        StringBuilder urlString = new StringBuilder();
        urlString.append("https://maps.googleapis.com/maps/api/directions/json");
        urlString.append("?origin=");// from
        urlString.append(Double.toString(sourcelat));
        urlString.append(",");
        urlString
                .append(Double.toString(sourcelog));
        urlString.append("&destination=");// to
        urlString
                .append(destlat);
        urlString.append(",");
        urlString.append(destlog);
        urlString.append("&sensor=false&mode=driving&alternatives=true");
        urlString.append("&key=".concat(context.getString(R.string.map_api_key)).concat(""));
        return urlString.toString();
    }

    public class OrderViewHolder extends RecyclerView.ViewHolder {
        ItemOrderlistBinding binding;

        public OrderViewHolder(@NonNull View itemView) {
            super(itemView);
            binding = ItemOrderlistBinding.bind(itemView);

        }

        public void setModel(PendingOrdersRoot.DataItem datum) {


            if (datum.getDate() != null) {
                binding.tvtime.setText(datum.getDate());
            }
            PendingOrdersRoot.Orderaddress addressObj = datum.getOrderaddress();

            if (addressObj != null && !addressObj.equals("")) {
                binding.tvCustomername.setText(addressObj.getFirstname());


                binding.tvaddress1.setText(addressObj.getArea().concat(", ").concat(addressObj.getCity()));
                binding.tvaddress2.setText(addressObj.getAddressLine()
                        + " \n" + addressObj.getArea() + " " + addressObj.getLandmark() + " " + addressObj.getPincode());


                //     binding.tvdistence.setText(datum.getDistance().concat(context.getString(R.string.km)));

                binding.orderid.setText("Order ID: ".concat(datum.getOrderId()));

                if (lastKnownLocation != null) {
                    getDistance(addressObj, binding);
                }

            }


            if (datum.getUser() != null) {

                Glide.with(binding.getRoot().getContext())
                        .load(Const.BASE_IMG_URL + datum.getUser().getImage())
                        .placeholder(R.drawable.user_place_holder)
                        .error(R.drawable.user_place_holder)
                        .circleCrop()
                        .into(binding.imgCustomer);

                itemView.setOnClickListener(v -> {
                    Intent intent = new Intent(context, OrderDetailActivity.class);
                    intent.putExtra("uid", datum.getUserId());
                    intent.putExtra("oid", datum.getOrderId());
                    intent.putExtra("from", "pending");
                    intent.putExtra("user", new Gson().toJson(datum.getUser()));
                    context.startActivity(intent);
                });
                binding.imgarrow.setOnClickListener(v -> {
                    Intent intent = new Intent(context, OrderDetailActivity.class);
                    intent.putExtra("uid", datum.getUserId());
                    intent.putExtra("oid", datum.getOrderId());
                    intent.putExtra("from", "pending");
                    intent.putExtra("user", new Gson().toJson(datum.getUser()));
                    context.startActivity(intent);
                });
            }

        }
    }

}
