package com.retrytech.deliveryboy.retrofit;

import com.retrytech.deliveryboy.models.CompleteOrderRoot;
import com.retrytech.deliveryboy.models.DeliveryBoyRoot;
import com.retrytech.deliveryboy.models.DistanceRoot;
import com.retrytech.deliveryboy.models.OrderDetailRoot;
import com.retrytech.deliveryboy.models.PendingOrdersRoot;
import com.retrytech.deliveryboy.models.ProfileRoot;
import com.retrytech.deliveryboy.models.RestResponse;
import com.retrytech.deliveryboy.models.SettingRoot;

import java.util.Map;

import okhttp3.MultipartBody;
import okhttp3.RequestBody;
import retrofit2.Call;
import retrofit2.http.Field;
import retrofit2.http.FormUrlEncoded;
import retrofit2.http.GET;
import retrofit2.http.Header;
import retrofit2.http.Multipart;
import retrofit2.http.POST;
import retrofit2.http.Part;
import retrofit2.http.PartMap;
import retrofit2.http.Query;

public interface RetrofitService {

    @GET("json")
    Call<DistanceRoot> getDistance(@Query("origins") String origin,
                                   @Query("destinations") String des,
                                   @Query("key") String key);

    @FormUrlEncoded
    @POST("DeliveryBoy/register")
    Call<DeliveryBoyRoot> login(@Header("apikey") String key,
                                @Field("username") String username,
                                @Field("password") String pwd,
                                @Field("device_type") String devicetype,
                                @Field("device_token") String devicetoken);

    @FormUrlEncoded
    @POST("DeliveryBoy/getPendingOrders")
    Call<PendingOrdersRoot> getPendingOrders(@Header("apikey") String key, @Header("token") String token,
                                             //  @Field("latitude") String username,
                                             //  @Field("longitude") String pwd,
                                             @Field("start") int start,
                                             @Field("count") int limit);

    @FormUrlEncoded
    @POST("DeliveryBoy/getCompletedOrders")
    Call<CompleteOrderRoot> getCompleteOrders(@Header("apikey") String key, @Header("token") String token,
                                              @Field("start") int start,
                                              @Field("count") int limit);

    @FormUrlEncoded
    @POST("DeliveryBoy/startDelivery")
    Call<RestResponse> startDelivery(@Header("apikey") String key, @Header("token") String token,
                                     @Field("order_id") String orderId);

    @FormUrlEncoded
    @POST("DeliveryBoy/completeDelivery")
    Call<RestResponse> completeDelivery(@Header("apikey") String key, @Header("token") String token,
                                        @Field("order_id") String orderId,
                                        @Field("payment") String payment);

    @FormUrlEncoded
    @POST("DeliveryBoy/onHoldDelivery")
    Call<RestResponse> onHoldDelivery(@Header("apikey") String key, @Header("token") String token,
                                      @Field("order_id") String orderId,
                                      @Field("reason") String reason);

    @FormUrlEncoded
    @POST("DeliveryBoy/getOrderDetails")
    Call<OrderDetailRoot> getOrdersDetail(@Header("apikey") String key, @Header("token") String token,
                                          @Field("order_id") String pwd);

    @POST("DeliveryBoy/getProfile")
    Call<ProfileRoot> getProfile(@Header("apikey") String key, @Header("token") String token);

    @POST("DeliveryBoy/logout")
    Call<RestResponse> logOut(@Header("apikey") String key, @Header("token") String token);

    @FormUrlEncoded
    @POST("DeliveryBoy/changeAvialableStatus")
    Call<RestResponse> changeStatus(@Header("apikey") String key, @Header("token") String token, @Field("is_avialable") Long status);

    @Multipart
    @POST("DeliveryBoy/updateProfile")
    Call<DeliveryBoyRoot> updateUser(@Header("apikey") String key,
                                     @Header("token") String token,
                                     @PartMap Map<String, RequestBody> partMap,
                                     @Part MultipartBody.Part requestBody);

    @POST("Order/getSettingData")
    Call<SettingRoot> getSetting(@Header("apikey") String key);
}
